@@ -22,7 +22,7 @@ true <- c(0.20470157, 0.20470157, 0.119012525, 0.119012525,
 
 ### estimations
 
-N.run <- 20
+N.run <- 10
 N.eval <- 20000
 Int1 <- matrix(, N.run, choose(d, 2))
 Int2 <- matrix(, N.run, choose(d, 2))
@@ -32,13 +32,13 @@ Int4 <- matrix(, N.run, choose(d, 2))
 for (i in 1:N.run) {
     print(paste("i=", i))
     Int1[i, ] <- estimateGraph(fun, d = d, N = N.eval, method = "FixLO", 
-        q.arg = list(min = domain[1], max = domain[2]))[3, ]
+        q.arg = list(min = domain[1], max = domain[2]))$tii[,1]
     Int2[i, ] <- estimateGraph(fun, d = d, N = N.eval, method = "FixFast", 
-        q.arg = list(min = domain[1], max = domain[2]))[3, ]
+        q.arg = list(min = domain[1], max = domain[2]))$tii[,1]
     Int3[i, ] <- estimateGraph(fun, d = d, N = N.eval, method = "RBD", 
-        q.arg = list(min = domain[1], max = domain[2]))[3, ]
+        q.arg = list(min = domain[1], max = domain[2]))$tii[,1]
     Int4[i, ] <- estimateGraph(fun, d = d, N = N.eval, method = "Sobol", 
-        q.arg = list(min = domain[1], max = domain[2]))[3, ]
+        q.arg = list(min = domain[1], max = domain[2]))$tii[,1]
 }
 
 ### boxplots
